@@ -214,10 +214,10 @@ def collate_metadata(metadata_dict):
             generate_collated_metadata(metadata_dict), key=count_input_paths
         )
     )
-    print(meta)
+    meta_se = tuple(g for k, g in meta if k == 1)[0]
+    meta_pe = tuple(g for k, g in meta if k == 2)[0]
+    print(meta_pe)
     raise SystemExit()
-    meta_se = tuple(g for k, g in meta if k == 1)
-    meta_pe = tuple(g for k, g in meta if k == 2)
     return meta_se, meta_pe
 
 
